# TABASSIST

## What's is about

This package has aim to assist you while you work with Tableau and takes some routine from your shoulders.

## INSTALATION

pip install tabassist

## USAGE

tabbassist check --file <absolute-workbook-path>

## DEVELOPMENT

1. virtualenv env
2. source ./env/bin/activate
3. pip install -r requarements.txt
4. (OPTIONAL)

    - pip install pycodestyle
    - pip install pydocstyle
    - pip install pytest
